var sketch = require('sketch')

var toggleAutoPreview = function(context) {
  var Settings = require('sketch/settings')
  var autoSave = Settings.sessionVariable('autoPreview')
  var isConnected = testConnection()
  if (isConnected === true) {
    if (autoSave === undefined) {
      sketch.UI.message(`Automatic Updates Enabled`)
      Settings.setSessionVariable('autoPreview', true)
    }else if (autoSave === true) {
      sketch.UI.message(`Automatic Updates Disabled`)
      Settings.setSessionVariable('autoPreview', false)
    }else if (autoSave === false) {
      sketch.UI.message(`Automatic Updates Enabled`)
      Settings.setSessionVariable('autoPreview', true)
    }
  }else{
    sketch.UI.message(`No Devices Connected`)
  }
}

var onRun = function(context) {
  var isConnected = testConnection()
  if (isConnected === true) {
    saveNow(false)
  }else{
    sketch.UI.message(`No Devices Connected`)
    Settings.setSessionVariable('autoPreview', false)
  }
}

var autoPreview = function(context) {
  var Settings = require('sketch/settings')
  var autoSave = Settings.sessionVariable('autoPreview')
  if (autoSave === undefined) {
    Settings.setSessionVariable('autoPreview', false)
  }else if (autoSave === true) {
    var isConnected = testConnection()
    if (isConnected === true) {
      saveNow(true)
    }else{
      sketch.UI.message(`No Devices Connected – Automatic Updates Unavailable`)
      Settings.setSessionVariable('autoPreview', false)
    }
  }
}

function saveNow(isAutomatic) {
  var document = sketch.getSelectedDocument()
  
  var selectedLayers = document.selectedLayers
  
  var selectedLayer = selectedLayers.reduce((initial, layer) => {
    return layer
  }, '')
  
  var selectedArtboard = selectedLayer.getParentArtboard()
  
  var options = null
  var exportName = null
  if (isAutomatic === false) {
    options = { scales: '3', overwriting: true, output: '~/Library/Caches/com.kylehalevi.Preview/', formats: 'png' }
    exportName = 'Preview'
  }else{
    options = { scales: '1', overwriting: true, output: '~/Library/Caches/com.kylehalevi.Preview/', formats: 'png' }
    exportName = 'Preview@3x'
  }
  
  if (selectedArtboard !== undefined) {
    var savedName = selectedArtboard.name
    selectedArtboard.name = exportName
    sketch.export(selectedArtboard, options)
    selectedArtboard.name = savedName
    
  }else{
    var savedName = selectedLayer.name
    selectedLayer.name = exportName
    sketch.export(selectedLayer, options)
    selectedLayer.name = savedName
  }
}

function testConnection() {
  try {
    let fileManager = NSFileManager.defaultManager();
    let cachesURL = fileManager.URLsForDirectory_inDomains(NSCachesDirectory, NSUserDomainMask).lastObject();
    let statusURL = cachesURL.URLByAppendingPathComponent("com.kylehalevi.Preview/status.json");
    var data = NSData.dataWithContentsOfURL(statusURL);
    var json = NSJSONSerialization.JSONObjectWithData_options_error(data, 0, nil)
    
    console.log(json["isConnected"])
    
    if (json["isConnected"] == 1) {
      return true
    }else{
      return false
    }
  } catch(e) {
    console.log("Exception: " + e);
    return false
  }
}